@@ -40,6 +40,11 @@ parser.add_argument(
     help='Theme was to clean the output.'
 )
 
+parser.add_argument(
+    '--presenter', action='store_true', default=False,
+    help='Presenter mode.'
+)
+
 parser.add_argument(
     '--themes', metavar='PATH',
     help='Path of the custom themes'
